Library interface for the Kermit CLI.
Re-exports algorithm and data structure types and provides the
compute_join helper for running joins from tuple inputs.
Modules
Functions
- compute_
join - Convenience function that builds relations from raw tuple vectors and runs a join, returning the result tuples.